#!bash

#	MAIN
#
#	target:
#		use a seguence of:
#			1) ATTACK SIMULATION
#			2) TEST
#			3) FIX
#		operations
#		to converge to attack-related fixed container
#		(
#			actualy:
#				PREPARE
#				ATTACK SIMULATION (*)
#				until(TEST) 
#				{
#					FIX
#					ATTACK SIMULATION (**)
#				}
#
#				rem0: 	faster convergence may be achieved 
#					by selecting (*) more "rough" then (**)
#		)
#
#	$src           - source container (native)
#	$mes           - message to be injected into destination container
#	$dest          - destination container
#	$dest_attacked - destination container after simulated attack
#	$attacker      - user-defined attack simulation script
#			 $attacker_args - attacker args


# input and output files:
	
	src=test.wav

	mes=message

	key=100

	dest=fixed.wav
	dest_attacked=attacked.wav

	# auxiliary dest
		dest_aux=f_test.wav

# log files
	prepare_log=log_prepare
	test_log=log_test
	fix_log=log_fix

# setup attacker
	attacker=attack_by_a-law.sh
	attacker_args="$dest $dest_attacked $src"



# setup dirs
bash setup_dirs.sh








#show file roles
echo "        original     = $src";
echo "        message      = $mes";
echo "        key          = $key";
echo "        destination  = $dest";
echo;
echo "        attacked wav = $dest_attacked";
echo "        attacker     = $attacker";



# FIRST prepare an input signal
echo;
echo;
echo "PREPARE...";
time ./steg --prepare $key $src $mes $dest >$prepare_log
echo;
echo;


# FIRST ATTACK SIMULATION
echo "ATTACK SIMULATION...";
time bash $attacker $attacker_args


echo "TEST...";
(( iter=1 ))
until (time ./steg --test $key $dest_attacked $mes >$test_log); do

	echo;
	echo;
	echo;
	echo "[$iter]"


	# FIX
	echo "    FIX...";
	if !(time ./steg --fix $key $src $mes $dest_aux $dest >$fix_log); then
		echo "WARNING: one or more slots in container destroyed by attacker";
		#mv --force $dest_aux $dest
		#break;
	fi;
	mv --force $dest_aux $dest
	
	



	# ATTACK SIMULATION
	echo "    ATTACK SIMULATION...";
	time bash $attacker $attacker_args

	(( iter=iter+1 ))

	echo "    TEST...";
done;

# remove patterns...
rm ./temp/J
rm ./temp/_J
rm ./temp/dr
rm ./temp/ns

echo;
echo;
echo;
echo "all OK";
